<?php
namespace FiloBlu\Flow\Model\From;

class Price extends AbstractFrom {
    
    /**
    * @var Monolog\Logger
    */
    protected $_logger;
    protected $_productFactory;

    /**
     * @param \Magento\Framework\Model\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\Model\ResourceModel\AbstractResource $resource
     * @param \Magento\Framework\Data\Collection\Db $resourceCollection
     * @param array $data
     */
    public function __construct(
        \Magento\Framework\Model\Context $context,
        \Magento\Framework\Registry $registry,
        \FiloBlu\Flow\Helper\Price $helper_price,
        \FiloBlu\Flow\Helper\Data $helper_flow,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        \Magento\Catalog\Model\ProductFactory $productFactory,
        array $data = []
    )
    {
        $this->_helper_price = $helper_price;
        $this->_helper_flow = $helper_flow;
        $this->_storeManager = $storeManager;
        $this->_productFactory = $productFactory;
        parent::__construct($context, $registry, null, null, $data);
    }

    /**
     * @return void
     */
    public function _construct()
    {
        $this->_init('FiloBlu\Flow\Model\ResourceModel\From\Price');
    }


    public function process() {

        $productSku = $this->getSku();
        $paese = $this->getPaese();
        $prezzo = $this->getPrezzo();
        // $valuta = $this->getValuta();

        $allStore = $this->_helper_flow->getStoreInWebsiteId();
        
        if(is_null($paese)){
            $paese = 'admin';
        }
        $storeId = $allStore[$paese]['store_id'];
        
        // $this->_logger->info($productSku . ' - ' . ' store_id= '.$storeId .' price: '.$prezzo);

        $productId = $this->_productFactory->create()->getIdBySku($productSku);

        if($productId){
            
            // salvo il prezzo sul prodotto semplice
            $product = $this->_productFactory->create()->setStoreId($storeId)->load($productId);
            // $product->setCurrencyCode($valuta);
            $product->setPrice($prezzo);
            $product->save();
        
            // salvo il prezzo sul prodotto configurabile padre
            $parent_product_id = \Magento\Framework\App\ObjectManager::getInstance()->create('Magento\ConfigurableProduct\Model\ResourceModel\Product\Type\Configurable')->getParentIdsByChild($productId);
            if(isset($parent_product_id[0])){
                
                $parent_product = $this->_productFactory->create()->setStoreId($storeId)->load($parent_product_id[0]);
                $parent_product->setStoreId($storeId);
                // $product->setCurrencyCode($valuta);
                $parent_product->setPrice($prezzo);
                $parent_product->save();
            }
            
        }

        return $this;

    }


}
